# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/command.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/command/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import zone_heating_regulator_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_zone__heating__regulator__pb2
from . import update_system_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_update__system__pb2
from . import update_lte_hysteresis_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_update__lte__hysteresis__pb2
from . import update_linux_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_update__linux__pb2
from . import unpair_ferroamp_core_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_unpair__ferroamp__core__pb2
from . import turn_signature_element_lights_on_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_turn__signature__element__lights__on__pb2
from . import turn_signature_element_lights_off_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_turn__signature__element__lights__off__pb2
from . import sync_ferroamp_devices_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_sync__ferroamp__devices__pb2
from . import sync_ferroamp_cts_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_sync__ferroamp__cts__pb2
from . import set_zone_setpoints_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__zone__setpoints__pb2
from . import set_wifi_credentials_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__wifi__credentials__pb2
from . import set_telemetry_interval_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__telemetry__interval__pb2
from . import set_target_hot_water_temperature_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__target__hot__water__temperature__pb2
from . import set_target_heat_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__target__heat__pb2
from . import set_sensor_sources_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__sensor__sources__pb2
from . import set_scheduled_heat_curve_deltas_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__scheduled__heat__curve__deltas__pb2
from . import set_room_temp_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__room__temp__setpoint__delta__pb2
from . import set_room_supply_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__room__supply__setpoint__delta__pb2
from . import set_pump_speed_settings_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__pump__speed__settings__pb2
from . import set_power_preference_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__power__preference__pb2
from . import set_outdoor_unit_current_limits_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__outdoor__unit__current__limits__pb2
from . import set_inline_heater_steps_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__inline__heater__steps__pb2
from . import set_inline_heater_ambient_threshold_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__inline__heater__ambient__threshold__pb2
from . import set_heating_cooling_thresholds_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__heating__cooling__thresholds__pb2
from . import set_heat_curves_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__heat__curves__pb2
from . import set_heat_curve_deltas_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__heat__curve__deltas__pb2
from . import set_flow_alarm_thresholds_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__flow__alarm__thresholds__pb2
from . import set_energy_balance_thresholds_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__energy__balance__thresholds__pb2
from . import set_diagnostic_poll_period_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__diagnostic__poll__period__pb2
from . import set_dhw_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__dhw__setpoint__delta__pb2
from . import set_cool_curves_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__cool__curves__pb2
from . import set_cool_curve_deltas_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__cool__curve__deltas__pb2
from . import set_away_mode_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__away__mode__pb2
from . import run_legionella_cycle_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_run__legionella__cycle__pb2
from . import rotate_certificate_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_rotate__certificate__pb2
from . import reset_legionella_schedule_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_reset__legionella__schedule__pb2
from . import remove_schedule_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_remove__schedule__pb2
from . import regenerate_thread_config_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_regenerate__thread__config__pb2
from . import reboot_device_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_reboot__device__pb2
from . import ping_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_ping__pb2
from . import pair_ferroamp_core_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_pair__ferroamp__core__pb2
from . import modbus_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_modbus__pb2
from . import install_firmware_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_install__firmware__pb2
from . import install_app_package_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_install__app__package__pb2
from . import forbid_lte_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_forbid__lte__pb2
from . import factory_reset_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_factory__reset__pb2
from . import enable_hot_water_heating_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_enable__hot__water__heating__pb2
from . import enable_force_heating_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_enable__force__heating__pb2
from . import enable_disable_heating_cooling_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_enable__disable__heating__cooling__pb2
from . import disconnect_wifi_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_disconnect__wifi__pb2
from . import disable_manual_mode_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_disable__manual__mode__pb2
from . import disable_hot_water_heating_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_disable__hot__water__heating__pb2
from . import disable_force_heating_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_disable__force__heating__pb2
from . import decommission_wall_thermostat_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_decommission__wall__thermostat__pb2
from . import deactivate_hot_water_boosting_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_deactivate__hot__water__boosting__pb2
from . import configure_time_zone_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_configure__time__zone__pb2
from . import configure_heat_pump_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_configure__heat__pump__pb2
from . import command_source_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_command__source__pb2
from . import clear_scheduled_heat_curve_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_clear__scheduled__heat__curve__delta__pb2
from . import clear_room_temp_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_clear__room__temp__setpoint__delta__pb2
from . import clear_room_supply_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_clear__room__supply__setpoint__delta__pb2
from . import clear_heat_curve_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_clear__heat__curve__delta__pb2
from . import clear_dhw_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_clear__dhw__setpoint__delta__pb2
from . import clear_cool_curve_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_clear__cool__curve__delta__pb2
from . import clear_away_mode_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_clear__away__mode__pb2
from . import allow_lte_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_allow__lte__pb2
from . import add_schedule_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_add__schedule__pb2
from . import activate_night_mode_for_one_hour_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_activate__night__mode__for__one__hour__pb2
from . import activate_hot_water_boosting_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_activate__hot__water__boosting__pb2
from . import acknowledge_errors_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_acknowledge__errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)device/heat_pump/command/v1/command.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\x1a\x12util/v1/uuid.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x38\x64\x65vice/heat_pump/command/v1/zone_heating_regulator.proto\x1a/device/heat_pump/command/v1/update_system.proto\x1a\x37\x64\x65vice/heat_pump/command/v1/update_lte_hysteresis.proto\x1a.device/heat_pump/command/v1/update_linux.proto\x1a\x36\x64\x65vice/heat_pump/command/v1/unpair_ferroamp_core.proto\x1a\x42\x64\x65vice/heat_pump/command/v1/turn_signature_element_lights_on.proto\x1a\x43\x64\x65vice/heat_pump/command/v1/turn_signature_element_lights_off.proto\x1a\x37\x64\x65vice/heat_pump/command/v1/sync_ferroamp_devices.proto\x1a\x33\x64\x65vice/heat_pump/command/v1/sync_ferroamp_cts.proto\x1a\x34\x64\x65vice/heat_pump/command/v1/set_zone_setpoints.proto\x1a\x36\x64\x65vice/heat_pump/command/v1/set_wifi_credentials.proto\x1a\x38\x64\x65vice/heat_pump/command/v1/set_telemetry_interval.proto\x1a\x42\x64\x65vice/heat_pump/command/v1/set_target_hot_water_temperature.proto\x1a\x31\x64\x65vice/heat_pump/command/v1/set_target_heat.proto\x1a\x34\x64\x65vice/heat_pump/command/v1/set_sensor_sources.proto\x1a\x41\x64\x65vice/heat_pump/command/v1/set_scheduled_heat_curve_deltas.proto\x1a>device/heat_pump/command/v1/set_room_temp_setpoint_delta.proto\x1a@device/heat_pump/command/v1/set_room_supply_setpoint_delta.proto\x1a\x39\x64\x65vice/heat_pump/command/v1/set_pump_speed_settings.proto\x1a\x36\x64\x65vice/heat_pump/command/v1/set_power_preference.proto\x1a\x41\x64\x65vice/heat_pump/command/v1/set_outdoor_unit_current_limits.proto\x1a\x39\x64\x65vice/heat_pump/command/v1/set_inline_heater_steps.proto\x1a\x45\x64\x65vice/heat_pump/command/v1/set_inline_heater_ambient_threshold.proto\x1a@device/heat_pump/command/v1/set_heating_cooling_thresholds.proto\x1a\x31\x64\x65vice/heat_pump/command/v1/set_heat_curves.proto\x1a\x37\x64\x65vice/heat_pump/command/v1/set_heat_curve_deltas.proto\x1a;device/heat_pump/command/v1/set_flow_alarm_thresholds.proto\x1a?device/heat_pump/command/v1/set_energy_balance_thresholds.proto\x1a<device/heat_pump/command/v1/set_diagnostic_poll_period.proto\x1a\x38\x64\x65vice/heat_pump/command/v1/set_dhw_setpoint_delta.proto\x1a\x31\x64\x65vice/heat_pump/command/v1/set_cool_curves.proto\x1a\x37\x64\x65vice/heat_pump/command/v1/set_cool_curve_deltas.proto\x1a/device/heat_pump/command/v1/set_away_mode.proto\x1a\x36\x64\x65vice/heat_pump/command/v1/run_legionella_cycle.proto\x1a\x34\x64\x65vice/heat_pump/command/v1/rotate_certificate.proto\x1a;device/heat_pump/command/v1/reset_legionella_schedule.proto\x1a\x31\x64\x65vice/heat_pump/command/v1/remove_schedule.proto\x1a:device/heat_pump/command/v1/regenerate_thread_config.proto\x1a/device/heat_pump/command/v1/reboot_device.proto\x1a&device/heat_pump/command/v1/ping.proto\x1a\x34\x64\x65vice/heat_pump/command/v1/pair_ferroamp_core.proto\x1a(device/heat_pump/command/v1/modbus.proto\x1a\x32\x64\x65vice/heat_pump/command/v1/install_firmware.proto\x1a\x35\x64\x65vice/heat_pump/command/v1/install_app_package.proto\x1a,device/heat_pump/command/v1/forbid_lte.proto\x1a/device/heat_pump/command/v1/factory_reset.proto\x1a:device/heat_pump/command/v1/enable_hot_water_heating.proto\x1a\x36\x64\x65vice/heat_pump/command/v1/enable_force_heating.proto\x1a@device/heat_pump/command/v1/enable_disable_heating_cooling.proto\x1a\x31\x64\x65vice/heat_pump/command/v1/disconnect_wifi.proto\x1a\x35\x64\x65vice/heat_pump/command/v1/disable_manual_mode.proto\x1a;device/heat_pump/command/v1/disable_hot_water_heating.proto\x1a\x37\x64\x65vice/heat_pump/command/v1/disable_force_heating.proto\x1a>device/heat_pump/command/v1/decommission_wall_thermostat.proto\x1a?device/heat_pump/command/v1/deactivate_hot_water_boosting.proto\x1a\x35\x64\x65vice/heat_pump/command/v1/configure_time_zone.proto\x1a\x35\x64\x65vice/heat_pump/command/v1/configure_heat_pump.proto\x1a\x30\x64\x65vice/heat_pump/command/v1/command_source.proto\x1a\x42\x64\x65vice/heat_pump/command/v1/clear_scheduled_heat_curve_delta.proto\x1a@device/heat_pump/command/v1/clear_room_temp_setpoint_delta.proto\x1a\x42\x64\x65vice/heat_pump/command/v1/clear_room_supply_setpoint_delta.proto\x1a\x38\x64\x65vice/heat_pump/command/v1/clear_heat_curve_delta.proto\x1a:device/heat_pump/command/v1/clear_dhw_setpoint_delta.proto\x1a\x38\x64\x65vice/heat_pump/command/v1/clear_cool_curve_delta.proto\x1a\x31\x64\x65vice/heat_pump/command/v1/clear_away_mode.proto\x1a+device/heat_pump/command/v1/allow_lte.proto\x1a.device/heat_pump/command/v1/add_schedule.proto\x1a\x42\x64\x65vice/heat_pump/command/v1/activate_night_mode_for_one_hour.proto\x1a=device/heat_pump/command/v1/activate_hot_water_boosting.proto\x1a\x34\x64\x65vice/heat_pump/command/v1/acknowledge_errors.proto\"\xcd\x30\n\x07\x43ommand\x12!\n\ncommand_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12(\n\x04time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x0e\x63ommand_source\x18\x11 \x01(\x0e\x32*.device.heat_pump.command.v1.CommandSource\x12\x41\n\rset_away_mode\x18\x05 \x01(\x0b\x32(.device.heat_pump.command.v1.SetAwayModeH\x00\x12\x45\n\x0f\x63lear_away_mode\x18\x06 \x01(\x0b\x32*.device.heat_pump.command.v1.ClearAwayModeH\x00\x12\\\n\x1b\x61\x63tivate_hot_water_boosting\x18\x07 \x01(\x0b\x32\x35.device.heat_pump.command.v1.ActivateHotWaterBoostingH\x00\x12`\n\x1d\x64\x65\x61\x63tivate_hot_water_boosting\x18\x08 \x01(\x0b\x32\x37.device.heat_pump.command.v1.DeactivateHotWaterBoostingH\x00\x12\x65\n set_target_hot_water_temperature\x18\t \x01(\x0b\x32\x39.device.heat_pump.command.v1.SetTargetHotWaterTemperatureH\x00\x12O\n\x14set_wifi_credentials\x18\n \x01(\x0b\x32/.device.heat_pump.command.v1.SetWifiCredentialsH\x00\x12T\n\x1a\x64\x65precated_set_target_heat\x18\x0b \x01(\x0b\x32*.device.heat_pump.command.v1.SetTargetHeatB\x02\x18\x01H\x00\x12@\n\x0cupdate_linux\x18\x10 \x01(\x0b\x32(.device.heat_pump.command.v1.UpdateLinuxH\x00\x12\x65\n turn_signature_element_lights_on\x18\x12 \x01(\x0b\x32\x39.device.heat_pump.command.v1.TurnSignatureElementLightsOnH\x00\x12g\n!turn_signature_element_lights_off\x18\x13 \x01(\x0b\x32:.device.heat_pump.command.v1.TurnSignatureElementLightsOffH\x00\x12L\n\x12\x61\x63knowledge_errors\x18\x14 \x01(\x0b\x32..device.heat_pump.command.v1.AcknowledgeErrorsH\x00\x12\x46\n\x0f\x64isconnect_wifi\x18\x15 \x01(\x0b\x32+.device.heat_pump.command.v1.DisconnectWiFiH\x00\x12U\n\x13install_app_package\x18\x16 \x01(\x0b\x32\x36.device.heat_pump.command.v1.InstallApplicationPackageH\x00\x12H\n\x10install_firmware\x18\x17 \x01(\x0b\x32,.device.heat_pump.command.v1.InstallFirmwareH\x00\x12M\n\x13\x63onfigure_heat_pump\x18\x18 \x01(\x0b\x32..device.heat_pump.command.v1.ConfigureHeatPumpH\x00\x12\x61\n\x1eset_room_supply_setpoint_delta\x18\x19 \x01(\x0b\x32\x37.device.heat_pump.command.v1.SetRoomSupplySetpointDeltaH\x00\x12\x65\n clear_room_supply_setpoint_delta\x18\x1a \x01(\x0b\x32\x39.device.heat_pump.command.v1.ClearRoomSupplySetpointDeltaH\x00\x12R\n\x16set_dhw_setpoint_delta\x18\x1b \x01(\x0b\x32\x30.device.heat_pump.command.v1.SetDhwSetpointDeltaH\x00\x12V\n\x18\x63lear_dhw_setpoint_delta\x18\x1c \x01(\x0b\x32\x32.device.heat_pump.command.v1.ClearDhwSetpointDeltaH\x00\x12L\n\x12rotate_certificate\x18\x1d \x01(\x0b\x32..device.heat_pump.command.v1.RotateCertificateH\x00\x12\x42\n\rfactory_reset\x18\x1e \x01(\x0b\x32).device.heat_pump.command.v1.FactoryResetH\x00\x12P\n\x15set_heat_curve_deltas\x18\x1f \x01(\x0b\x32/.device.heat_pump.command.v1.SetHeatCurveDeltasH\x00\x12T\n\x17\x63lear_heat_curve_deltas\x18  \x01(\x0b\x32\x31.device.heat_pump.command.v1.ClearHeatCurveDeltasH\x00\x12K\n\x12set_zone_setpoints\x18! \x01(\x0b\x32-.device.heat_pump.command.v1.SetZoneSetpointsH\x00\x12\x31\n\x04ping\x18\" \x01(\x0b\x32!.device.heat_pump.command.v1.PingH\x00\x12X\n\x19set_flow_alarm_thresholds\x18# \x01(\x0b\x32\x33.device.heat_pump.command.v1.SetFlowAlarmThresholdsH\x00\x12\x63\n\x1fset_outdoor_unit_current_limits\x18$ \x01(\x0b\x32\x38.device.heat_pump.command.v1.SetOutdoorUnitCurrentLimitsH\x00\x12\x42\n\rupdate_system\x18% \x01(\x0b\x32).device.heat_pump.command.v1.UpdateSystemH\x00\x12P\n\x15set_cool_curve_deltas\x18& \x01(\x0b\x32/.device.heat_pump.command.v1.SetCoolCurveDeltasH\x00\x12T\n\x17\x63lear_cool_curve_deltas\x18\' \x01(\x0b\x32\x31.device.heat_pump.command.v1.ClearCoolCurveDeltasH\x00\x12\x45\n\x0fset_heat_curves\x18( \x01(\x0b\x32*.device.heat_pump.command.v1.SetHeatCurvesH\x00\x12\x45\n\x0fset_cool_curves\x18) \x01(\x0b\x32*.device.heat_pump.command.v1.SetCoolCurvesH\x00\x12U\n\x17\x65nable_heating_function\x18* \x01(\x0b\x32\x32.device.heat_pump.command.v1.EnableHeatingFunctionH\x00\x12W\n\x18\x64isable_heating_function\x18+ \x01(\x0b\x32\x33.device.heat_pump.command.v1.DisableHeatingFunctionH\x00\x12U\n\x17\x65nable_cooling_function\x18, \x01(\x0b\x32\x32.device.heat_pump.command.v1.EnableCoolingFunctionH\x00\x12W\n\x18\x64isable_cooling_function\x18- \x01(\x0b\x32\x33.device.heat_pump.command.v1.DisableCoolingFunctionH\x00\x12\x64\n activate_night_mode_for_one_hour\x18. \x01(\x0b\x32\x38.device.heat_pump.command.v1.ActivateNightModeForOneHourH\x00\x12W\n\x18regenerate_thread_config\x18/ \x01(\x0b\x32\x33.device.heat_pump.command.v1.RegenerateThreadConfigH\x00\x12Z\n\x1aset_diagnostic_poll_period\x18\x30 \x01(\x0b\x32\x34.device.heat_pump.command.v1.SetDiagnosticPollPeriodH\x00\x12V\n\x18\x65nable_hot_water_heating\x18\x31 \x01(\x0b\x32\x32.device.heat_pump.command.v1.EnableHotWaterHeatingH\x00\x12X\n\x19\x64isable_hot_water_heating\x18\x32 \x01(\x0b\x32\x33.device.heat_pump.command.v1.DisableHotWaterHeatingH\x00\x12\x44\n\x0emodbus_request\x18\x33 \x01(\x0b\x32*.device.heat_pump.command.v1.ModbusRequestH\x00\x12O\n\x14run_legionella_cycle\x18\x34 \x01(\x0b\x32/.device.heat_pump.command.v1.RunLegionellaCycleH\x00\x12Y\n\x19reset_legionella_schedule\x18\x35 \x01(\x0b\x32\x34.device.heat_pump.command.v1.ResetLegionellaScheduleH\x00\x12_\n\x1c\x64\x65\x63ommission_wall_thermostat\x18\x36 \x01(\x0b\x32\x37.device.heat_pump.command.v1.DecommissionWallThermostatH\x00\x12\x62\n\x1eset_heating_cooling_thresholds\x18\x37 \x01(\x0b\x32\x38.device.heat_pump.command.v1.SetHeatingCoolingThresholdsH\x00\x12T\n\x17set_pump_speed_settings\x18\x38 \x01(\x0b\x32\x31.device.heat_pump.command.v1.SetPumpSpeedSettingsH\x00\x12T\n\x17set_inline_heater_steps\x18\x39 \x01(\x0b\x32\x31.device.heat_pump.command.v1.SetInlineHeaterStepsH\x00\x12K\n\x12set_sensor_sources\x18: \x01(\x0b\x32-.device.heat_pump.command.v1.SetSensorSourcesH\x00\x12`\n\x1dset_energy_balance_thresholds\x18; \x01(\x0b\x32\x37.device.heat_pump.command.v1.SetEnergyBalanceThresholdsH\x00\x12M\n\x13\x64isable_manual_mode\x18< \x01(\x0b\x32..device.heat_pump.command.v1.DisableManualModeH\x00\x12\x42\n\rreboot_device\x18= \x01(\x0b\x32).device.heat_pump.command.v1.RebootDeviceH\x00\x12]\n\x1cset_room_temp_setpoint_delta\x18> \x01(\x0b\x32\x35.device.heat_pump.command.v1.SetRoomTempSetpointDeltaH\x00\x12\x61\n\x1e\x63lear_room_temp_setpoint_delta\x18? \x01(\x0b\x32\x37.device.heat_pump.command.v1.ClearRoomTempSetpointDeltaH\x00\x12\x63\n\x1fset_scheduled_heat_curve_deltas\x18@ \x01(\x0b\x32\x38.device.heat_pump.command.v1.SetScheduledHeatCurveDeltasH\x00\x12g\n!clear_scheduled_heat_curve_deltas\x18\x41 \x01(\x0b\x32:.device.heat_pump.command.v1.ClearScheduledHeatCurveDeltasH\x00\x12S\n\x16set_telemetry_interval\x18\x42 \x01(\x0b\x32\x31.device.heat_pump.command.v1.SetTelemetryIntervalH\x00\x12:\n\tallow_lte\x18\x43 \x01(\x0b\x32%.device.heat_pump.command.v1.AllowLteH\x00\x12<\n\nforbid_lte\x18\x44 \x01(\x0b\x32&.device.heat_pump.command.v1.ForbidLteH\x00\x12Q\n\x15update_lte_hysteresis\x18\x45 \x01(\x0b\x32\x30.device.heat_pump.command.v1.UpdateLteHysteresisH\x00\x12M\n\x13\x63onfigure_time_zone\x18\x46 \x01(\x0b\x32..device.heat_pump.command.v1.ConfigureTimeZoneH\x00\x12k\n#set_inline_heater_ambient_threshold\x18G \x01(\x0b\x32<.device.heat_pump.command.v1.SetInlineHeaterAmbientThresholdH\x00\x12@\n\x0c\x61\x64\x64_schedule\x18H \x01(\x0b\x32(.device.heat_pump.command.v1.AddScheduleH\x00\x12\x46\n\x0fremove_schedule\x18I \x01(\x0b\x32+.device.heat_pump.command.v1.RemoveScheduleH\x00\x12K\n\x12pair_ferroamp_core\x18J \x01(\x0b\x32-.device.heat_pump.command.v1.PairFerroampCoreH\x00\x12S\n\x16zone_heating_regulator\x18K \x01(\x0b\x32\x31.device.heat_pump.command.v1.ZoneHeatingRegulatorH\x00\x12O\n\x14unpair_ferroamp_core\x18L \x01(\x0b\x32/.device.heat_pump.command.v1.UnpairFerroampCoreH\x00\x12Q\n\x15sync_ferroamp_devices\x18M \x01(\x0b\x32\x30.device.heat_pump.command.v1.SyncFerroampDevicesH\x00\x12I\n\x11sync_ferroamp_cts\x18N \x01(\x0b\x32,.device.heat_pump.command.v1.SyncFerroampCtsH\x00\x12O\n\x14\x65nable_force_heating\x18O \x01(\x0b\x32/.device.heat_pump.command.v1.EnableForceHeatingH\x00\x12Q\n\x15\x64isable_force_heating\x18P \x01(\x0b\x32\x30.device.heat_pump.command.v1.DisableForceHeatingH\x00\x12O\n\x14set_power_preference\x18Q \x01(\x0b\x32/.device.heat_pump.command.v1.SetPowerPreferenceH\x00\x42\x08\n\x06group0B\xb6\x01\n\x1b\x64\x65vice.heat_pump.command.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033device.heat_pump.command.v1B\014CommandProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_COMMAND'].fields_by_name['deprecated_set_target_heat']._loaded_options = None
  _globals['_COMMAND'].fields_by_name['deprecated_set_target_heat']._serialized_options = b'\030\001'
  _globals['_COMMAND']._serialized_start=4141
  _globals['_COMMAND']._serialized_end=10362
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....state.v1 import state_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9device/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto\x12$device.heat_pump.telemetry.v1.ccv.v1\x1a%device/heat_pump/state/v1/state.proto\"\'\n\rEnergyBalance\x12\x16\n\x0e\x65nergy_balance\x18\x01 \x01(\x05\"\x93\x01\n\x12InlineHeaterStatus\x12\x11\n\tis_active\x18\x01 \x01(\x08\x12\"\n\x1ainline_heater_step1_active\x18\x02 \x01(\x08\x12\"\n\x1ainline_heater_step2_active\x18\x03 \x01(\x08\x12\"\n\x1ainline_heater_step3_active\x18\x04 \x01(\x08\"n\n\x15\x43irculationPumpStatus\x12\x14\n\x0cpump0_active\x18\x01 \x01(\x08\x12\x14\n\x0cpump1_active\x18\x02 \x01(\x08\x12\x14\n\x0cpump2_active\x18\x03 \x01(\x08\x12\x13\n\x0bpump0_speed\x18\x04 \x01(\x05\"\xcf\x01\n\x0bHeatingMode\x12\x1c\n\x10\x64\x65precated_state\x18\x01 \x01(\rB\x02\x18\x01\x12\x1e\n\x16\x61mbient_temp_avarage1h\x18\x02 \x01(\x02\x12\x1e\n\x16\x61mbient_temp_avarage3h\x18\x03 \x01(\x02\x12\x1f\n\x17\x61mbient_temp_avarage24h\x18\x04 \x01(\x02\x12\x41\n\x0fpump_mode_state\x18\x05 \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\"\xd8\x02\n\x11\x45nergyCalculation\x12\"\n\x1a\x63urrent_electrical_power_w\x18\x01 \x01(\r\x12!\n\x19\x65lectrical_energy_cum_kwh\x18\x02 \x01(\r\x12\x16\n\x0e\x63urrent_phase0\x18\x03 \x01(\x02\x12\x16\n\x0e\x63urrent_phase1\x18\x04 \x01(\x02\x12\x16\n\x0e\x63urrent_phase2\x18\x05 \x01(\x02\x12\x16\n\x0evoltage_phase0\x18\x06 \x01(\x02\x12\x16\n\x0evoltage_phase1\x18\x07 \x01(\x02\x12\x16\n\x0evoltage_phase2\x18\x08 \x01(\x02\x12 \n\x18\x65lectrical_energy_cum_wh\x18\t \x01(\r\x12\x1c\n\x14water_energy_cum_kwh\x18\n \x01(\r\x12\x1b\n\x13water_energy_cum_wh\x18\x0b \x01(\r\x12\x0f\n\x07\x63op_now\x18\x0c \x01(\x02\"\x96\x08\n\x0cMegmetStatus\x12\x17\n\x0frequested_state\x18\x01 \x01(\r\x12*\n\"compressor_need_percent_calculated\x18\x02 \x01(\x05\x12+\n#compressor_limit_percent_calculated\x18\x03 \x01(\x05\x12\x1e\n\x16\x63urrent_operation_mode\x18\x04 \x01(\r\x12\x18\n\x10\x61\x63_input_voltage\x18\x05 \x01(\r\x12\x18\n\x10\x61\x63_input_current\x18\x06 \x01(\r\x12\"\n\x1a\x63ompressor_frequency_limit\x18\x07 \x01(\r\x12 \n\x18\x63ompressor_running_speed\x18\x08 \x01(\r\x12\x1a\n\x12\x64\x63_fan_speed_limit\x18\t \x01(\r\x12\x1d\n\x15\x64\x63_fan1_running_speed\x18\n \x01(\r\x12\x1d\n\x15\x64\x63_fan2_running_speed\x18\x0b \x01(\r\x12\x10\n\x08\x65\x65v_step\x18\x0c \x01(\r\x12\x16\n\x0erelay_feedback\x18\r \x01(\r\x12\x1b\n\x13\x61mbient_temperature\x18\x0e \x01(\x02\x12#\n\x1b\x65vaporator_coil_temperature\x18\x0f \x01(\x02\x12!\n\x19gas_discharge_temperature\x18\x10 \x01(\x02\x12\x1e\n\x16gas_return_temperature\x18\x11 \x01(\x02\x12\x17\n\x0f\x63ompressor_code\x18\x12 \x01(\r\x12\x1f\n\x17outdoor_unit_dip_switch\x18\x13 \x01(\r\x12\x1b\n\x13\x65vaporator_pressure\x18\x14 \x01(\x02\x12\x1a\n\x12\x63ondenser_pressure\x18\x15 \x01(\x02\x12\x1f\n\x17outdoor_unit_defrosting\x18\x16 \x01(\x08\x12(\n outdoor_unit_pcb_program_version\x18\x17 \x01(\r\x12\'\n\x1foutdoor_unit_pcb_eeprom_version\x18\x18 \x01(\r\x12&\n\x1emain_control_board_item_number\x18\x19 \x01(\r\x12\x1e\n\x16\x63ondensing_temperature\x18\x1a \x01(\x02\x12\x1f\n\x17\x65vaporating_temperature\x18\x1b \x01(\x02\x12\x1f\n\x17inlet_water_temperature\x18\x1c \x01(\x02\x12 \n\x18outlet_water_temperature\x18\x1d \x01(\x02\x12\x1e\n\x16inner_coil_temperature\x18\x1e \x01(\x02\x12\x1a\n\x12outdoor_unit_model\x18\x1f \x01(\t\x12\"\n\x1aoutdoor_unit_serial_number\x18  \x01(\t\"\xbf\x01\n\tSmartGrid\x12\x44\n\x05state\x18\x01 \x01(\x0e\x32\x35.device.heat_pump.telemetry.v1.ccv.v1.SmartGrid.State\"l\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_BLOCKED\x10\x01\x12\x10\n\x0cSTATE_NORMAL\x10\x02\x12\x14\n\x10STATE_ENCOURAGED\x10\x03\x12\x11\n\rSTATE_ORDERED\x10\x04\"\x94\x03\n\x0bValveStatus\x12]\n\x19\x64hw_heating_cooling_valve\x18\x01 \x01(\x0e\x32:.device.heat_pump.telemetry.v1.ccv.v1.ValveStatus.Position\x12\x1d\n\x15mixing_valve1_opening\x18\x02 \x01(\x08\x12\x1d\n\x15mixing_valve2_opening\x18\x03 \x01(\x08\x12\x1d\n\x15mixing_valve1_closing\x18\x04 \x01(\x08\x12\x1d\n\x15mixing_valve2_closing\x18\x05 \x01(\x08\x12)\n!mixing_valve1_calculated_position\x18\x06 \x01(\x05\x12)\n!mixing_valve2_calculated_position\x18\x07 \x01(\x05\"T\n\x08Position\x12\x18\n\x14POSITION_UNSPECIFIED\x10\x00\x12\x10\n\x0cPOSITION_DHW\x10\x01\x12\x1c\n\x18POSITION_HEATING_COOLING\x10\x02\"y\n\x13\x43\x61lculatedSetpoints\x12\x0e\n\x06supply\x18\x01 \x01(\x02\x12\x14\n\x0csupply_zone1\x18\x02 \x01(\x02\x12\x14\n\x0csupply_zone2\x18\x03 \x01(\x02\x12\x12\n\ntemp_room1\x18\x04 \x01(\x02\x12\x12\n\ntemp_room2\x18\x05 \x01(\x02\"\xe7\x03\n\x0cSensorValues\x12(\n outdoor_unit_ambient_temperature\x18\x01 \x01(\x02\x12\'\n\x1foutdoor_unit_supply_temperature\x18\x02 \x01(\x02\x12\'\n\x1foutdoor_unit_return_temperature\x18\x03 \x01(\x02\x12+\n#outdoor_unit_inner_coil_temperature\x18\x04 \x01(\x02\x12(\n indoor_unit_dhw_tank_temperature\x18\x05 \x01(\x02\x12&\n\x1eindoor_unit_supply_temperature\x18\x06 \x01(\x02\x12,\n$indoor_unit_supply_temperature_zone1\x18\x07 \x01(\x02\x12,\n$indoor_unit_supply_temperature_zone2\x18\x08 \x01(\x02\x12*\n\"indoor_unit_room_temperature_zone1\x18\t \x01(\x02\x12*\n\"indoor_unit_room_temperature_zone2\x18\n \x01(\x02\x12\x13\n\x0b\x66low_meter1\x18\x0b \x01(\x02\x12\x13\n\x0b\x66low_meter2\x18\x0c \x01(\x02\x42\xeb\x01\n$device.heat_pump.telemetry.v1.ccv.v1B\x12TelemetryDataProtoP\x01\xa2\x02\x03TVC\xaa\x02#Device.HeatPump.Telemetry.V1.Ccv.V1\xca\x02#Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\xe2\x02/Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\\GPBMetadata\xea\x02(Device::HeatPump::Telemetry::V1::Ccv::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.telemetry.v1.ccv.v1.telemetry_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$device.heat_pump.telemetry.v1.ccv.v1B\022TelemetryDataProtoP\001\242\002\003TVC\252\002#Device.HeatPump.Telemetry.V1.Ccv.V1\312\002#Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\342\002/Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\\GPBMetadata\352\002(Device::HeatPump::Telemetry::V1::Ccv::V1'
  _globals['_HEATINGMODE'].fields_by_name['deprecated_state']._loaded_options = None
  _globals['_HEATINGMODE'].fields_by_name['deprecated_state']._serialized_options = b'\030\001'
  _globals['_ENERGYBALANCE']._serialized_start=138
  _globals['_ENERGYBALANCE']._serialized_end=177
  _globals['_INLINEHEATERSTATUS']._serialized_start=180
  _globals['_INLINEHEATERSTATUS']._serialized_end=327
  _globals['_CIRCULATIONPUMPSTATUS']._serialized_start=329
  _globals['_CIRCULATIONPUMPSTATUS']._serialized_end=439
  _globals['_HEATINGMODE']._serialized_start=442
  _globals['_HEATINGMODE']._serialized_end=649
  _globals['_ENERGYCALCULATION']._serialized_start=652
  _globals['_ENERGYCALCULATION']._serialized_end=996
  _globals['_MEGMETSTATUS']._serialized_start=999
  _globals['_MEGMETSTATUS']._serialized_end=2045
  _globals['_SMARTGRID']._serialized_start=2048
  _globals['_SMARTGRID']._serialized_end=2239
  _globals['_SMARTGRID_STATE']._serialized_start=2131
  _globals['_SMARTGRID_STATE']._serialized_end=2239
  _globals['_VALVESTATUS']._serialized_start=2242
  _globals['_VALVESTATUS']._serialized_end=2646
  _globals['_VALVESTATUS_POSITION']._serialized_start=2562
  _globals['_VALVESTATUS_POSITION']._serialized_end=2646
  _globals['_CALCULATEDSETPOINTS']._serialized_start=2648
  _globals['_CALCULATEDSETPOINTS']._serialized_end=2769
  _globals['_SENSORVALUES']._serialized_start=2772
  _globals['_SENSORVALUES']._serialized_end=3259
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/power.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/state/v1/power.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%device/heat_pump/state/v1/power.proto\x12\x19\x64\x65vice.heat_pump.state.v1\"#\n\x12\x43urrentTransformer\x12\r\n\x05ratio\x18\x01 \x01(\r\"\xa2\x01\n\x17\x43urrentTransformerState\x12:\n\nscan_state\x18\x01 \x01(\x0e\x32&.device.heat_pump.state.v1.CtScanState\x12K\n\x14\x63urrent_transformers\x18\x02 \x03(\x0b\x32-.device.heat_pump.state.v1.CurrentTransformer\"\x1e\n\x08Inverter\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"\x1d\n\x07\x42\x61ttery\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"#\n\rPhotovoltaics\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"\xbd\x01\n\x0cPowerDevices\x12\x35\n\x08inverter\x18\x03 \x03(\x0b\x32#.device.heat_pump.state.v1.Inverter\x12?\n\rphotovoltaics\x18\x04 \x03(\x0b\x32(.device.heat_pump.state.v1.Photovoltaics\x12\x35\n\tbatteries\x18\x05 \x03(\x0b\x32\".device.heat_pump.state.v1.Battery\"\xda\x01\n\nPowerState\x12\x1a\n\x12paired_core_serial\x18\x01 \x01(\t\x12\x1f\n\x17paired_core_app_version\x18\x02 \x01(\t\x12\x38\n\x07\x64\x65vices\x18\x03 \x01(\x0b\x32\'.device.heat_pump.state.v1.PowerDevices\x12U\n\x19\x63urrent_transformer_state\x18\x04 \x01(\x0b\x32\x32.device.heat_pump.state.v1.CurrentTransformerState*h\n\x0b\x43tScanState\x12\x1d\n\x19\x43T_SCAN_STATE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43T_SCAN_STATE_NOT_SCANNING\x10\x01\x12\x1a\n\x16\x43T_SCAN_STATE_SCANNING\x10\x02\x42\xaa\x01\n\x19\x64\x65vice.heat_pump.state.v1B\nPowerProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.power_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031device.heat_pump.state.v1B\nPowerProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_CTSCANSTATE']._serialized_start=783
  _globals['_CTSCANSTATE']._serialized_end=887
  _globals['_CURRENTTRANSFORMER']._serialized_start=68
  _globals['_CURRENTTRANSFORMER']._serialized_end=103
  _globals['_CURRENTTRANSFORMERSTATE']._serialized_start=106
  _globals['_CURRENTTRANSFORMERSTATE']._serialized_end=268
  _globals['_INVERTER']._serialized_start=270
  _globals['_INVERTER']._serialized_end=300
  _globals['_BATTERY']._serialized_start=302
  _globals['_BATTERY']._serialized_end=331
  _globals['_PHOTOVOLTAICS']._serialized_start=333
  _globals['_PHOTOVOLTAICS']._serialized_end=368
  _globals['_POWERDEVICES']._serialized_start=371
  _globals['_POWERDEVICES']._serialized_end=560
  _globals['_POWERSTATE']._serialized_start=563
  _globals['_POWERSTATE']._serialized_end=781
# @@protoc_insertion_point(module_scope)